# combo - content management system
# Copyright (C) 2014-2018  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.conf import settings


class Engines(object):
    """Singleton object that serves as a registry of classes providing search
    engines."""

    def __init__(self):
        self.engines = {}

    def register(self, key, **options):
        self.engines[key] = options

    def get(self, key):
        if key in settings.COMBO_SEARCH_SERVICES:
            return settings.COMBO_SEARCH_SERVICES[key]
        return self.engines.get(key)

    def get_engines(self):
        data = {}
        for key in settings.COMBO_SEARCH_SERVICES:
            data[key] = settings.COMBO_SEARCH_SERVICES[key]
        for key in self.engines:
            data[key] = self.engines[key]
        return data

engines = Engines()  # singleton object
